@@ -1,5 +1,4 @@
 import datetime
-from optparse import make_option
 
 from django.core.management.base import BaseCommand
 from django.utils.timezone import now
@@ -9,10 +8,13 @@ from ...models import Email
 
 class Command(BaseCommand):
     help = 'Place deferred messages back in the queue.'
-    option_list = BaseCommand.option_list + (
-        make_option('-d', '--days', type='int', default=90,
-            help="Cleanup mails older than this many days, defaults to 90."),
-    )
+
+    def add_arguments(self, parser):
+        parser.add_argument('-d', '--days',
+            type=int,
+            default=90,
+            help="Cleanup mails older than this many days, defaults to 90."
+            )
 
     def handle(self, verbosity, days, **options):
         # Delete mails and their related logs and queued created before X days
